<a id="mypy-boto3-cloud9"></a>

# mypy-boto3-cloud9

[![PyPI - mypy-boto3-cloud9](https://img.shields.io/pypi/v/mypy-boto3-cloud9.svg?color=blue)](https://pypi.org/project/mypy-boto3-cloud9)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-cloud9.svg?color=blue)](https://pypi.org/project/mypy-boto3-cloud9)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-cloud9?color=blue)](https://pypistats.org/packages/mypy-boto3-cloud9)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Cloud9 1.18.53](https://boto3.amazonaws.com/v1/documentation/api/1.18.53/reference/services/cloud9.html#Cloud9)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-cloud9 docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-cloud9](#mypy-boto3-cloud9)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Cloud9` service.

```bash
python -m pip install boto3-stubs[cloud9]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[cloud9]` in your environment:
  `python -m pip install 'boto3-stubs[cloud9]'`

Both type checking and auto-complete should work for `Cloud9` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[cloud9]` in your environment:
  `python -m pip install 'boto3-stubs[cloud9]'`

Both type checking and auto-complete should work for `Cloud9` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[cloud9]` in your environment:
  `python -m pip install 'boto3-stubs[cloud9]'`
- Run `mypy` as usual

Type checking should work for `Cloud9` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[cloud9]` in your environment:
  `python -m pip install 'boto3-stubs[cloud9]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Cloud9` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`Cloud9Client` provides annotations for `boto3.client("cloud9")`.

```python
import boto3

from mypy_boto3_cloud9 import Cloud9Client

client: Cloud9Client = boto3.client("cloud9")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: Cloud9Client = session.client("cloud9")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_cloud9.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_cloud9 import Cloud9Client
from mypy_boto3_cloud9.paginator import (
    DescribeEnvironmentMembershipsPaginator,
    ListEnvironmentsPaginator,
)

client: Cloud9Client = boto3.client("cloud9")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_environment_memberships_paginator: DescribeEnvironmentMembershipsPaginator = client.get_paginator("describe_environment_memberships")
list_environments_paginator: ListEnvironmentsPaginator = client.get_paginator("list_environments")
```

<a id="literals"></a>

### Literals

`mypy_boto3_cloud9.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_cloud9.literals import (
    ConnectionTypeType,
    DescribeEnvironmentMembershipsPaginatorName,
    EnvironmentLifecycleStatusType,
    EnvironmentStatusType,
    EnvironmentTypeType,
    ListEnvironmentsPaginatorName,
    ManagedCredentialsActionType,
    ManagedCredentialsStatusType,
    MemberPermissionsType,
    PermissionsType,
    ServiceName,
    PaginatorName,
)

def check_value(value: ConnectionTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_cloud9.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_cloud9.type_defs import (
    CreateEnvironmentEC2RequestRequestTypeDef,
    CreateEnvironmentEC2ResultTypeDef,
    CreateEnvironmentMembershipRequestRequestTypeDef,
    CreateEnvironmentMembershipResultTypeDef,
    DeleteEnvironmentMembershipRequestRequestTypeDef,
    DeleteEnvironmentRequestRequestTypeDef,
    DescribeEnvironmentMembershipsRequestRequestTypeDef,
    DescribeEnvironmentMembershipsResultTypeDef,
    DescribeEnvironmentStatusRequestRequestTypeDef,
    DescribeEnvironmentStatusResultTypeDef,
    DescribeEnvironmentsRequestRequestTypeDef,
    DescribeEnvironmentsResultTypeDef,
    EnvironmentLifecycleTypeDef,
    EnvironmentMemberTypeDef,
    EnvironmentTypeDef,
    ListEnvironmentsRequestRequestTypeDef,
    ListEnvironmentsResultTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    ResponseMetadataTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateEnvironmentMembershipRequestRequestTypeDef,
    UpdateEnvironmentMembershipResultTypeDef,
    UpdateEnvironmentRequestRequestTypeDef,
)

def get_structure() -> CreateEnvironmentEC2RequestRequestTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-cloud9` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-cloud9 docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
